@@ -19,6 +19,8 @@ class SearchController extends Controller
 		if (strpos($request->term,'=')) {
 			list($attr,$value) = explode('=',$request->term,2);
 			$value = trim($value);
+			$ao = $so
+				->schema('attributetypes',$attr);
 
 			$result = collect();
 
@@ -26,18 +28,37 @@ class SearchController extends Controller
 				$search = (new Entry)
 					->in($base);
 
-				$search = ($x=Str::startsWith($value,'*'))
-					? $search->whereEndsWith($attr,substr($value,1))
-					: $search->whereStartsWith($attr,$value);
+				$wildcard = FALSE;
 
-				$result = $result->merge($search->get());
+				// If the attribute supports substring queries
+				if ($ao->sub_str_rule) {
+					if (Str::startsWith($value,'*')) {
+						$wildcard = TRUE;
+						$search = $search->whereEndsWith($attr,substr($value,1));
+
+					} elseif ($wildcard=Str::endsWith($value,'*')) {
+						$search = $search->whereStartsWith($attr,substr($value,0,-1));
+
+					} else
+						$search = $search->whereStartsWith($attr,$value);
+
+				} else {
+					$search = $search->where($attr,'*');
+				}
+
+				$result = $result->merge($search->get($attr));
 			}
 
 			return $result
 				->map(fn($item)=>[
 					'name'=>$item->getDN(),
 					'value'=>Crypt::encryptString($item->getDN()),
-					'category'=>sprintf('%s: [%s=%s%s]',__('Result'),$attr,$value,($x ? '' : '*'))
+					'category'=>sprintf('%s%s: [%s=%s%s]',
+						__('Result'),
+						$ao->sub_str_rule ? '' : sprintf('(%s)', __('No Sub Search')),
+						$attr,
+						$ao->sub_str_rule ? $value : '',
+						($wildcard ? '' : '*'))
 				]);
 
 		// We are searching for an attribute
